@@ -262,12 +262,13 @@ pub fn fraction(value: Float, options: Options, colors: &Colors, n: usize) -> St
                             }
                             (true, false) =>
                             {
+                                div *= recip.clone().pow(if i == 1 { 2 } else { 3 });
                                 format!(
                                     "{sign}{}/{}{}{}{}",
                                     if mul.is_empty() { "1" } else { &mul },
                                     if i == 1 { "sqrt" } else { "cbrt" },
                                     lb,
-                                    recip,
+                                    div,
                                     rb
                                 )
                             }
@@ -361,11 +362,7 @@ pub fn rationalize(value: Float, options: Options) -> Option<(Integer, Integer)>
         {
             recip *= mult.clone();
             let last = recip.clone() / if j == 0 { &recip } else { &first };
-            let recip = match recip.to_integer()
-            {
-                Some(n) => n,
-                None => return None,
-            };
+            let recip = recip.to_integer()?;
             let last = (last + recip.clone() * value.trunc())
                 .to_integer()
                 .unwrap_or_default();
