@@ -176,6 +176,7 @@ pub fn functions() -> HashSet<&'static str>
         "betaP",
         "betaC",
         "slope",
+        "taylor",
         "lim",
         "limit",
         "D",
@@ -252,6 +253,8 @@ pub fn functions() -> HashSet<&'static str>
         "lognorm_pdf",
         "binomial_pmf",
         "geometric_pmf",
+        "poly",
+        "polynomial",
         "rand_lognorm",
         "rand_binomial",
         "rand_geometric",
@@ -435,6 +438,7 @@ pub fn functions_with_args() -> HashSet<&'static str>
         "beta_pdf(x,α,β)",
         "beta_cdf(x,α,β)",
         "slope(a,f(a),x(,nth)(,combine))",
+        "taylor(a,f(a),p,n(,x))",
         "lim(a,f(a),x(,side))",
         "area(a,f(a),start,end(,nth)(,combine)",
         "arclength(a,f(a),start,end)",
@@ -485,6 +489,7 @@ pub fn functions_with_args() -> HashSet<&'static str>
         "lognorm_pdf(x,μ,σ)",
         "binomial_pmf(k,n,p)",
         "geometric_pmf(k,p)",
+        "polynomial(vec/mat,x)",
         "rand_lognorm(μ,σ)",
         "rand_binomial(n,p)",
         "rand_geometric(k,p)",
